jupymake: A Python wrapper for the polymake shell
=================================================

Description
-----------

The Python module JuPyMake provides an interface to polymake.

License
-------

-  GPL v2


Upstream Contact
----------------

   https://github.com/polymake/JuPyMake

Special Update/Build Instructions
---------------------------------
